Learn R Programming

HierO (version 0.2)

HierO: GUI for hierarchical data

Description

HierO is a graphical user interface (GUI) tool for calculating optimal statistical power and sample size for hierarchical data structure.

Usage

HierO()

Arguments

Details

HierO constructs a user defined sample size optimization problem to GAMS (General Algebraic Modeling System) form and uses Rneos package to send the problem to NEOS server for solving.

References

http://onlinelibrary.wiley.com/doi/10.1111/stan.12026/abstract