HierO: GUI for hierarchical data
Description
HierO is a graphical user interface (GUI) tool for calculating optimal statistical power and sample size for hierarchical data structure.Details
HierO constructs a user defined sample size optimization problem to GAMS (General Algebraic Modeling System) form and uses Rneos package to send the problem to NEOS server for solving.